==> tutti-ui-swing-2.5.1-sources.jar: fr/ifremer/tutti/ui/swing/content/category/SaveSampleCategoryModelAction.java <==
package fr.ifremer.tutti.ui.swing.content.category;

/*
 * #%L
 * Tutti :: UI
 * $Id: SaveSampleCategoryModelAction.java 1170 2013-09-13 16:21:34Z tchemit $
 * $HeadURL: http://svn.forge.codelutin.com/svn/tutti/tags/tutti-2.5.1/tutti-ui-swing/src/main/java/fr/ifremer/tutti/ui/swing/content/category/SaveSampleCategoryModelAction.java $
 * %%
 * Copyright (C) 2012 - 2013 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import fr.ifremer.tutti.persistence.entities.data.SampleCategoryModel;
import fr.ifremer.tutti.ui.swing.util.action.AbstractTuttiAction;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * To save the sample category model.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 2.4
 */
public class SaveSampleCategoryModelAction extends AbstractTuttiAction<EditSampleCategoryModelUIModel, EditSampleCategoryModelUI, EditSampleCategoryModelUIHandler> {

    /** Logger. */
    private static final Log log =
            LogFactory.getLog(SaveSampleCategoryModelAction.class);

    public SaveSampleCategoryModelAction(EditSampleCategoryModelUIHandler handler) {
        super(handler, true);
    }

    @Override
    public void doAction() throws Exception {
        EditSampleCategoryModelUIModel model = getModel();

        SampleCategoryModel bean = model.toBean();

        if (log.isInfoEnabled()) {
            log.info("Will save sampleCategoryModel: " + bean);
        }
        getConfig().getServiceConfig().getPersistenceConfig().setSampleCategoryModel(bean);

        getConfig().save();

        getDataContext().loadSampleCategoryModel(bean);

        model.setModify(false);

    }
}

==> tutti-ui-swing-2.6-sources.jar: fr/ifremer/tutti/ui/swing/content/category/SaveSampleCategoryModelAction.java <==
package fr.ifremer.tutti.ui.swing.content.category;

/*
 * #%L
 * Tutti :: UI
 * $Id: SaveSampleCategoryModelAction.java 1170 2013-09-13 16:21:34Z tchemit $
 * $HeadURL: http://svn.forge.codelutin.com/svn/tutti/tags/tutti-2.6/tutti-ui-swing/src/main/java/fr/ifremer/tutti/ui/swing/content/category/SaveSampleCategoryModelAction.java $
 * %%
 * Copyright (C) 2012 - 2013 Ifremer
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

import fr.ifremer.tutti.persistence.entities.data.SampleCategoryModel;
import fr.ifremer.tutti.ui.swing.util.action.AbstractTuttiAction;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * To save the sample category model.
 *
 * @author tchemit <chemit@codelutin.com>
 * @since 2.4
 */
public class SaveSampleCategoryModelAction extends AbstractTuttiAction<EditSampleCategoryModelUIModel, EditSampleCategoryModelUI, EditSampleCategoryModelUIHandler> {

    /** Logger. */
    private static final Log log =
            LogFactory.getLog(SaveSampleCategoryModelAction.class);

    public SaveSampleCategoryModelAction(EditSampleCategoryModelUIHandler handler) {
        super(handler, true);
    }

    @Override
    public void doAction() throws Exception {
        EditSampleCategoryModelUIModel model = getModel();

        SampleCategoryModel bean = model.toBean();

        if (log.isInfoEnabled()) {
            log.info("Will save sampleCategoryModel: " + bean);
        }
        getConfig().getServiceConfig().getPersistenceConfig().setSampleCategoryModel(bean);

        getConfig().save();

        getDataContext().loadSampleCategoryModel(bean);

        model.setModify(false);

    }
}
